Dynamic Loaded Column Chart

<div id="wrap"> <select id="model" class="flat-select" onChange={() => this.changeData()} > <option value="iphone5">iPhone 5</option> <option value="iphone6">iPhone 6</option> <option value="iphone7">iPhone 7</option> </select> <div id="chart-year"> <ReactApexChart options={this.state.options} series={this.state.series} type="bar" height={400} /> </div> <div id="chart-quarter"> <ReactApexChart options={this.state.optionsQuarter} series={this.state.seriesQuarter} type="bar" height={400} /> </div> </div>